import React from "react";
import ImagePreview from "./ImagePreview";
import MarkdownPreview from "./MarkdownPreview";
import PdfPreview from "./PdfPreview";
import TxtPreview from "./TxtPreview";

export interface FilePreviewerProps {
  fileUrl: string;
  fileName: string;
  fullscreen?: boolean;
}

const getExtension = (fileName: string) => {
  const parts = fileName.split(".");
  return parts.length > 1 ? parts.pop()!.toLowerCase() : "";
};

const FilePreviewer: React.FC<FilePreviewerProps> = ({ fileUrl, fileName, fullscreen }) => {
  const ext = getExtension(fileName);

  if (["png", "jpg", "jpeg", "gif"].includes(ext)) {
    return <ImagePreview fileUrl={fileUrl} fileName={fileName} fullscreen={fullscreen} />;
  }
  if (ext === "md") {
    return <MarkdownPreview fileUrl={fileUrl} />;
  }
  if (ext === "pdf") {
    return <PdfPreview fileUrl={fileUrl} />;
  }
  if (ext === "txt") {
    return <TxtPreview fileUrl={fileUrl} />;
  }
  return <div>Anteprima non disponibile per questo tipo di file.</div>;
};

export default FilePreviewer;
