import React, { useState } from "react";
import { Document, Page, pdfjs } from "react-pdf";
import pdfjsWorker from 'pdfjs-dist/build/pdf.worker?url';

pdfjs.GlobalWorkerOptions.workerSrc = pdfjsWorker;

interface PdfPreviewProps {
  fileUrl: string;
}

const PdfPreview: React.FC<PdfPreviewProps> = ({ fileUrl }) => {
  const [numPages, setNumPages] = useState<number>(0);
  const [pageNumber, setPageNumber] = useState<number>(1);

  return (
    <div style={{ textAlign: "center" }}>
      <Document file={fileUrl} onLoadSuccess={({ numPages }) => setNumPages(numPages)}>
        <Page pageNumber={pageNumber} />
      </Document>
      <div style={{ marginTop: 8 }}>
        <button onClick={() => setPageNumber((p) => Math.max(1, p - 1))} disabled={pageNumber <= 1}>
          Pagina precedente
        </button>
        <span style={{ margin: "0 8px" }}>
          Pagina {pageNumber} di {numPages}
        </span>
        <button onClick={() => setPageNumber((p) => Math.min(numPages, p + 1))} disabled={pageNumber >= numPages}>
          Pagina successiva
        </button>
      </div>
    </div>
  );
};

export default PdfPreview;
